import 'elementorModules';
import BaseHandler = elementorModules.frontend.handlers.Base;
import BaseSettings = elementorModules.frontend.handlers.BaseSettings;

import './countdown.scss';
import * as elementorModules from "elementorModules";

interface CountdownSettings extends BaseSettings {
    selectors: {
        root: string,
        days: string,
        hours: string,
        minutes: string,
        seconds: string,
    },
}

export default class Countdown extends BaseHandler {

    private intervalId?: NodeJS.Timeout;

    constructor(options: BaseSettings) {
        super(options);


    }

    getDefaultElements() {
       const selectors = this.getSettings('selectors');

        return {
            $root: this.$element.find(selectors.root),
            $days: this.$element.find(selectors.days),
            $hours: this.$element.find(selectors.hours),
            $minutes: this.$element.find(selectors.minutes),
            $seconds: this.$element.find(selectors.seconds),
        }
    }

    getDefaultSettings(): CountdownSettings {
        return {
            selectors: {
                root: '.inti-countdown',
                days: '.inti-countdown-days',
                hours: '.inti-countdown-hours',
                minutes: '.inti-countdown-minutes',
                seconds: '.inti-countdown-seconds',
            },
        }
    }

    onInit() {
        super.onInit();

        this.update();
        this.intervalId = setInterval(this.update.bind(this), 1000);
    }

    onDestroy() {
        super.onDestroy();

        if (this.intervalId !== undefined) {
            clearInterval(this.intervalId);
        }
    }

    update() {
        const elements = this.getDefaultElements();
        const target = new Date(Date.parse(this.getDefaultElements().$root.data('target')));
        let time = Math.floor((target.getTime() - Date.now()) / 1000);

        const days = Math.floor(time / 86400);
        time = time % 86400;

        elements.$days.find('.inti-countdown-value').html(days.toString());
        elements.$days.find('.inti-countdown-label').html(this.daysLabel(days));

        const hours = Math.floor(time / 3600);
        time = time % 3600;

        elements.$hours.find('.inti-countdown-value').html(hours.toString());
        elements.$hours.find('.inti-countdown-label').html(this.hoursLabel(hours));

        const minutes = Math.floor(time / 60);

        elements.$minutes.find('.inti-countdown-value').html(minutes.toString());
        elements.$minutes.find('.inti-countdown-label').html(this.minutesLabel(minutes));

        const seconds = time % 60;

        elements.$seconds.find('.inti-countdown-value').html(seconds.toString());
        elements.$seconds.find('.inti-countdown-label').html(this.secondsLabel(seconds));
    }

    daysLabel(value: number) {
        value = parseInt(value.toString().split('').pop() || '');
        return (value > 1 || value === 0) ? 'Dana' : 'Dan';
    }

    hoursLabel(value: number) {
        value = parseInt(value.toString().split('').pop() || '');
        return (value > 4 || value === 0) ? 'Sati' : (value > 1 ? 'Sata' : 'Sat');
    }

    minutesLabel(value: number) {
        value = parseInt(value.toString().split('').pop() || '');
        return (value > 4 || value === 0) ? 'Minuta' : (value > 1 ? 'Minute' : 'Minuta');
    }

    secondsLabel(value: number) {
        value = parseInt(value.toString().split('').pop() || '');
        return (value > 4 || value === 0) ? 'Sekundi' : (value > 1 ? 'Sekunde' : 'Sekunda');
    }
}
