<?php
declare(strict_types=1);

namespace Inti\Elementor;

use Inti\Media\Service\ImageManager;
use Laminas\ConfigAggregator\ArrayProvider;
use Laminas\ConfigAggregator\ConfigAggregator;
use Laminas\ConfigAggregator\PhpFileProvider;
use Laminas\ServiceManager\ServiceManager;
use Mezzio\Application;
use Mezzio\Container;
use Mezzio\Middleware\ErrorResponseGenerator;

use function defined;

require dirname(__DIR__) . '/vendor/autoload.php';
chdir(dirname(__DIR__));

$config = (new ConfigAggregator([
    \Inti\App\ConfigProvider::class,
    \Inti\Wp\ConfigProvider::class,
    ConfigProvider::class,

    new PhpFileProvider(__DIR__ . '/config.local.php'),
    new ArrayProvider([
        'media' => [
            ImageManager::class => [
                'root' => __DIR__ . '/media',
            ],
        ],
        'dependencies' => [
            'factories' => [
                ErrorResponseGenerator::class => Container\WhoopsErrorResponseGeneratorFactory::class,
                'Mezzio\Whoops' => Container\WhoopsFactory::class,
                'Mezzio\WhoopsPageHandler' => Container\WhoopsPageHandlerFactory::class,
            ],
        ],
        'whoops' => [
            'json_exceptions' => [
                'display' => true,
                'show_trace' => true,
                'ajax_only' => true,
            ],
        ],
    ])
]))->getMergedConfig();

$container = new ServiceManager($config['dependencies']);
$container->setService('config', $config);

/** @var Application $app */
$app = $container->get(Application::class);
$app->run();

if (defined('WP_USE_THEMES')) {
    exit;
}
