<?php
declare(strict_types=1);

namespace Inti\Elementor\Plugin;

use Elementor\Core\DynamicTags\Manager;
use Inti\Wp\Plugin\PluginInterface;

use function add_action;
use function is_callable;

/**
 * Class RegisterTags
 *
 * @package Inti\Elementor\Plugin
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-elementor
 */
final class RegisterTags implements PluginInterface
{
    private array $tags;

    public function run(?array $options = null): void
    {
        $this->tags = $options ?? [];

        if (!empty($this->tags)) {
            add_action('elementor/dynamic_tags/register_tags', [$this, 'register_tags'], PHP_INT_MAX);
        }
    }

    public function register_tags(Manager $manager): void
    {
        foreach ($this->tags as $tag) {
            if (is_callable($tag)) {
                $tag($manager);
            } else {
                $manager->register_tag($tag);
            }
        }
    }
}
