<?php
declare(strict_types=1);

namespace Inti\Elementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Core\Kits\Documents\Tabs\Global_Colors;
use Elementor\Widget_Base;
use function date;
use function printf;
use function sprintf;

/**
 * Class Countdown
 *
 * @package Inti\Elementor\Widget
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-elementor
 */
final class Countdown extends Widget_Base
{
    public function get_categories(): array
    {
        return ['inti'];
    }

    public function get_name(): string
    {
        return 'inti_countdown';
    }

    public function get_title(): string
    {
        return 'Odbrojavanje';
    }

    public function get_icon(): string
    {
        return 'eicon-countdown';
    }

    public function get_script_depends(): array
    {
        return ['inti-widget-countdown'];
    }

    public function get_style_depends(): array
    {
        return ['inti-widget-countdown'];
    }

    protected function _register_controls()
    {
        $this->start_controls_section('inti_countdown_section', [
            'label' => 'Odbrojavanje',
            'tab' => Controls_Manager::TAB_CONTENT,
        ]);

        $this->add_control('target', [
            'label' => 'Vrijeme do kojeg odbrojavamo',
            'type' => Controls_Manager::DATE_TIME,
            'picker_options' => [
                'minDate' => date('Y-m-d'),
                'time_24hr' => true,
            ],
        ]);

        $this->add_control('display_settings', [
            'label' => 'Prikaz',
            'type' => Controls_Manager::HEADING,
        ]);

        $this->add_control('align_widget', [
            'label' => 'Poravnanje',
            'type' => Controls_Manager::CHOOSE,
            'options' => [
                'left' => [
                    'title' => 'Lijevo',
                    'icon' => 'eicon-text-align-left',
                ],
                'center' => [
                    'title' => 'Sredina',
                    'icon' => 'eicon-text-align-center',
                ],
                'right' => [
                    'title' => 'Desno',
                    'icon' => 'eicon-text-align-right',
                ],
            ],
            'selectors' => [
                '{{WRAPPER}}' => 'text-align: {{VALUE}};',
            ],
        ]);

        $this->add_control('show_days', [
            'label' => 'Dani',
            'type' => Controls_Manager::SWITCHER,
            'default' => 'yes',
        ]);

        $this->add_control('show_hours', [
            'label' => 'Sati',
            'type' => Controls_Manager::SWITCHER,
            'default' => 'yes',
        ]);

        $this->add_control('show_minutes', [
            'label' => 'Minute',
            'type' => Controls_Manager::SWITCHER,
            'default' => 'yes',
        ]);

        $this->add_control('show_seconds', [
            'label' => 'Sekunde',
            'type' => Controls_Manager::SWITCHER,
            'default' => 'yes',
        ]);

        $this->add_control('label_settings', [
            'label' => 'Etikete',
            'type' => Controls_Manager::HEADING,
        ]);

        $this->add_control('hide_labels', [
            'label' => 'Sakrij etikete',
            'type' => Controls_Manager::SWITCHER,
            'default' => '',
        ]);

        $this->end_controls_section();

        $this->start_controls_section('inti_countdown_tile', [
            'label' => 'Pločica',
            'tab' => Controls_Manager::TAB_STYLE,
        ]);

        $this->add_control('tile_size', [
            'label' => 'Veličina',
            'type' => Controls_Manager::SELECT,
            'default' => 'md',
            'options' => [
                'md' => 'Srednja',
                'sm' => 'Mala',
            ],
        ]);

        $this->add_control('tile_bgcolor', [
            'label' => 'Pozadinska boja',
            'type' => Controls_Manager::COLOR,
            'global' => [
                'default' => Global_Colors::COLOR_PRIMARY,
            ],
            'selectors' => [
                '{{WRAPPER}} .inti-countdown-tile' => 'background-color: {{VALUE}}',
            ],
        ]);

        $this->end_controls_section();
    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();

        printf(
            '<div class="inti-countdown inti-countdown-%s" data-target="%s">%s%s%s%s</div>',
            $settings['tile_size'],
            $settings['target'],
            $settings['show_days'] === 'yes' ? $this->render_tile('Dana', 'days') : '',
            $settings['show_hours'] === 'yes' ? $this->render_tile('Sati', 'hours') : '',
            $settings['show_minutes'] === 'yes' ? $this->render_tile('Minuta', 'minutes') : '',
            $settings['show_seconds'] === 'yes' ? $this->render_tile('Sekundi', 'seconds') : ''
        );
    }

    private function render_tile(string $label, string $suffix): string
    {
        $settings = $this->get_settings_for_display();

        return sprintf(
            '<div class="inti-countdown-tile inti-countdown-%s">%s%s</div>',
            $suffix,
            '<span class="inti-countdown-value">0</span>',
            $settings['hide_labels'] !== 'yes' ? sprintf('<span class="inti-countdown-label">%s</span>', $label) : '',
        );
    }
}
