<?php
declare(strict_types=1);

namespace Inti\Elementor\Widget\Form;

use Elementor\Controls_Manager;
use function explode;
use function is_string;
use function trim;

/**
 * Class Select
 *
 * @package Inti\Elementor\Widget\Form
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-elementor
 */
class Select extends AbstractFormWidget
{
    public function get_categories(): array
    {
        return ['inti-form'];
    }

    public function get_name(): string
    {
        return 'inti_form_select';
    }

    public function get_title(): string
    {
        return 'Odabir';
    }

    protected function register_controls(): void
    {
        $this->start_controls_section('options_section', [
            'label' => 'Opcije',
            'tab' => Controls_Manager::TAB_CONTENT,
        ]);

        $this->add_control('options', [
            'type' => Controls_Manager::TEXTAREA,
            'description' => 'Unesite svaku opciju na zasebnoj liniji. Za ralikovanje između '
                . 'oznake i vrijednosti, odvojite ih s pipe znakom ("|"). Npr.: Ime Kategorije|-ime-kategorije.',
        ]);

        $this->end_controls_section();

        $this->register_form_controls();
    }

    protected function render_element(): void
    {
        $settings = $this->get_settings();

        $this->add_render_attribute([
            'element-wrapper' => [
                'class' => [

                ],
            ],
            'field-wrapper' => [
                'class' => [
                    'inti-element-select-wrapper'
                ],
            ],
            'field' => [
                'class' => [

                ],
            ],
        ]);
        ?>
        <div <?= $this->get_render_attribute_string('field-wrapper'); ?>>
            <select <?= $this->get_render_attribute_string('field'); ?>>
                <?php $this->render_options(); ?>
            </select>
        </div>
        <?php
    }

    protected function render_options(): void
    {
        foreach ($this->get_options() as $value => $label) {
            printf('<option value="%s">%s</option>', $value, $label);
        }
    }

    protected function get_options(): array
    {
        $rawOptions = $this->get_settings_for_display('options');

        if (is_string($rawOptions) && !empty($rawOptions)) {
            foreach (explode("\n", $rawOptions ?? '') as $option) {
                [$label, $value] = explode('|', trim($option), 2);
                $options[$value ?? $label] = $label;
            }
        }

        return $options ?? [];
    }
}
