<?php
declare(strict_types=1);

namespace Inti\Elementor\Widget\Form;

use Elementor\Controls_Manager;
use WP_Taxonomy;
use function get_taxonomies;
use function get_terms;
use function is_string;

/**
 * Class TaxonomySelect
 *
 * @package Inti\Elementor\Widget\Form
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-elementor
 */
final class SelectTaxonomy extends Select
{
    public function get_categories(): array
    {
        return ['inti-form'];
    }

    public function get_name(): string
    {
        return 'inti_form_select_taxonomy';
    }

    public function get_title(): string
    {
        return 'Odabir taksonomije';
    }

    public function register_controls(): void
    {
        $this->start_controls_section('taxonomy_section', [
            'label' => 'Taksonomija',
            'tab' => Controls_Manager::TAB_CONTENT,
        ]);

        $this->add_control('taxonomy', [
            'label' => 'Taksonomija',
            'type' => Controls_Manager::SELECT,
            'options' => ['' => ''] + $this->get_taxonomies(),
            'default' => '',
        ]);

        $this->end_controls_section();

        $this->register_form_controls();
    }

    private function get_taxonomies(): array
    {

        /** @var WP_Taxonomy $taxonomy */
        foreach (get_taxonomies([], 'object') as $taxonomy) {
            $taxonomies[$taxonomy->name] = $taxonomy->label;
        }

        return $taxonomies ?? [];
    }

    protected function get_options(): array
    {
        $taxonomy = $this->get_settings_for_display('taxonomy');

        if (!is_string($taxonomy) || empty($taxonomy)) {
            return [];
        }

        $terms = get_terms([
            'parent' => 0,
            'taxonomy' => $taxonomy,
        ]);

        $options = ['' => ''];
        foreach ($terms as $term) {
            $options[$term->term_id] = $term->name;
        }

        return $options ?? [];
    }
}
